@@ -2,14 +2,11 @@
 #'
 #' View full documentation of vis.js on network
 #' 
-#' @param viewer : Set to NULL to open in a browser
 #' 
 #' @examples
 #'
-#' # minimal example
 #' \dontrun{
 #' visDocumentation()
-#' visDocumentation(NULL)
 #' }
 #' 
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
@@ -23,14 +20,7 @@
 #' @importFrom  utils browseURL
 #' @references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
 #'
-visDocumentation <- function(viewer = getOption("viewer")){
-  if (!is.null(viewer)){
-    tempDir <- tempdir()
-    ctrl <- file.copy(from = system.file("docjs", package = "visNetwork"), 
-              to = tempDir, overwrite = TRUE , recursive = TRUE)
-    viewer(paste0(tempDir, "/docjs/network/index.html"))
-  }else{
+visDocumentation <- function(){
     browseURL(system.file("docjs/network/index.html", package = "visNetwork"))
-  }
 }
 
