@@ -4,15 +4,15 @@
 #'
 #' @param graph : a visNetwork object
 #' @param id : String. Default to undefined. The id of the node. The id is mandatory for nodes and they have to be unique. This should obviously be set per node, not globally.
-#' @param shape : String. Default to 'ellipse'. The shape defines what the node looks like. There are two types of nodes. One type has the label inside of it and the other type has the label underneath it. The types with the label inside of it are: ellipse, circle, database, box, text. The ones with the label outside of it are: image, circularImage, diamond, dot, star, triangle, triangleDown, square and icon.
-#' @param size : Number. Default to 25. The size is used to determine the size of node shapes that do not have the label inside of them. These shapes are: image, circularImage, diamond, dot, star, triangle, triangleDown, square and icon
+#' @param shape : String. Default to 'ellipse'. The shape defines what the node looks like. There are two types of nodes. One type has the label inside of it and the other type has the label underneath it. The types with the label inside of it are: ellipse, circle, database, box, text. The ones with the label outside of it are: image, circularImage, diamond, dot, star, triangle, triangleDown, hexagon, square and icon.
+#' @param size : Number. Default to 25. The size is used to determine the size of node shapes that do not have the label inside of them. These shapes are: image, circularImage, diamond, dot, star, triangle, triangleDown, hexagon, square and icon
 #' @param title : String or Element. Default to undefined. Title to be displayed when the user hovers over the node. The title can be an HTML element or a string containing plain text or HTML.
 #' @param value : Number. Default to undefined. When a value is set, the nodes will be scaled using the options in the scaling object defined above.
 #' @param x : Number. Default to undefined. This gives a node an initial x position. When using the hierarchical layout, either the x or y position is set by the layout engine depending on the type of view. The other value remains untouched. When using stabilization, the stabilized position may be different from the initial one. To lock the node to that position use the physics or fixed options.
 #' @param y : Number. Default to undefined. This gives a node an initial y position. When using the hierarchical layout, either the x or y position is set by the layout engine depending on the type of view. The other value remains untouched. When using stabilization, the stabilized position may be different from the initial one. To lock the node to that position use the physics or fixed options. 
 #' @param label : String. Default to undefined. The label is the piece of text shown in or under the node, depending on the shape.
 #' @param level : Number. Default to undefined. When using the hierarchical layout, the level determines where the node is going to be positioned.
-#' @param group : String. Default to undefined. When not undefined, the group of node(s)
+#' @param group : String. Default to undefined. When not undefined, the node will belong to the defined group. Styling information of that group will apply to this node. Node specific styling overrides group styling. 
 #' @param hidden : Boolean. Default to false. When true, the node will not be shown. It will still be part of the physics simulation though!
 #' @param image : List or String. Default to undefined. When the shape is set to image or circularImage, this option should be the URL to an image. If the image cannot be found, the brokenImage option can be used.
 #'    \itemize{
@@ -25,23 +25,24 @@
 #' @param borderWidthSelected : Number. Default to 2. The width of the border of the node when it is selected. If left at undefined, double the borderWidth will be used.
 #' @param brokenImage : String. Undefined. When the shape is set to image or circularImage, this option can be an URL to a backup image in case the URL supplied in the image option cannot be resolved
 #' @param labelHighlightBold : Boolean. Default to true. Determines whether or not the label becomes bold when the node is selected.
-#' @param color : String | named list.	Color for the node. Can be 'rgba(120,32,14,1)', '#97C2FC' (hexa notation on 7 char without transparency) or 'red'. Can be just one color, or a list with several elements :
+#' @param color : String | named list.	Color for the node. Can be 'rgba(120,32,14,1)', '#D2E5FF' (hexa notation on 7 char without transparency) or 'red'. Can be just one color, or a list with several elements :
 #' \itemize{
-#'  \item{"background"}{ : String. Default to '#97C2FC'. Background color for the node.}
+#'  \item{"background"}{ : String. Default to '#D2E5FF'. Background color for the node.}
 #'  \item{"border"}{ : String. Default to '#2B7CE9'. Border color for the node.}
 #'  \item{"highlight"}{ : String | named list, 	Color of the node when selected.
 #'    \itemize{
-#'      \item{"background"}{ : String. Default to '#97C2FC'. Background color for the node when selected.}
+#'      \item{"background"}{ : String. Default to '#D2E5FF'. Background color for the node when selected.}
 #'      \item{"border"}{ : String. Default to '#2B7CE9'. Border color for the node when selected.}
 #'    }
 #'  }
 #'  \item{"hover"}{ : named list, when the hover option is enabled
 #'    \itemize{
-#'      \item{"background"}{ : String. Default to '#2B7CE9'. Border color of the node when selected.}
+#'      \item{"background"}{ : String. Default to '#D2E5FF'. Background color of the node when the node is hovered over and the hover option is enabled.}
 #'      \item{"border"}{ : String. Default to '#2B7CE9'. Border color of the node when the node is hovered over and the hover option is enabled.}
 #'    }
 #'  }
 #'}
+#' @param opacity :	Number. Overall opacity of a node (overrides any opacity on border, background, image, and shadow)
 #' @param fixed : Boolean | named list. Default to false. When true, the node will not move but IS part of the physics simulation. When defined as an list, movement in either X or Y direction can be disabled.
 #' \itemize{
 #'  \item{"x"}{ : Boolean. When true, the node will not move in the X direction.}
@@ -60,12 +61,13 @@
 #'  \item{"vadjust, multi, bold, ital, boldital, mono"}{See \link{visDocumentation}}
 #'}
 #'
-#' @param icon : Named list. These options are only used when the shape is set to 'icon'.
+#' @param icon : Named list. These options are only used when the shape is set to 'icon'. See \link{addFontAwesome}, \link{addIonicons}
 #' \itemize{
-#'  \item{"face"}{ : String. Default to 'FontAwesome'. These options are only used when the shape is set to icon. The possible options for the face are: 'FontAwesome' and 'Ionicons'.}
+#'  \item{"face"}{ : String. Default to 'FontAwesome'. These options are only used when the shape is set to icon. The possible options for the face are: 'FontAwesome', "'Font Awesome 5 Free'", and 'Ionicons'.}
 #'  \item{"code"}{ : String. Default to undefined. This is the code of the icon, for example '\\uf007'.}
 #'  \item{"size"}{ : Number. Default to 50. The size of the icon.}
 #'  \item{"color"}{ : String. Default to '#2B7CE9'. The color of the icon.}
+#'  \item{"weight"}{ : Number or String. Default to undefined. This allows for weight to be forced regardless of selection status. For example Font Awesome 5 doesn't work properly unless weight is forced to 'bold' or 700 (This is done automatically in visNetwork). If this option is set then selection is indicated by bigger size instead of bold font face. }
 #'}
 #'
 #' @param shadow : Boolean | named list. Default to false. When true, the node casts a shadow using the default settings. This can be further refined by supplying a list
@@ -93,20 +95,15 @@
 #'  \item{"customScalingFunction"}{ : Function. If nodes have value fields, this function determines how the size of the nodes are scaled based on their values.}
 #'}
 #'
-#' @param shapeProperties : Named list. This object contains configuration for specific shapes. 
-#' \itemize{
-#'  \item{"borderDashes"}{ : Vector or Boolean. Default to	false. This property applies to all shapes that have borders. You set the dashes by supplying an Vector Vector formart: [dash length, gap length]. You can also use a Boolean, false is disable and true is default [5,15].}
-#'  \item{"borderRadius"}{ : Number. Default to	6. This property is used only for the box shape. It allows you to determine the roundness of the corners of the shape.}
-#'  \item{"interpolation"}{ : 	Boolean. Default to	true. This property only applies to the image and circularImage shapes. When true, the image is resampled when scaled down, resulting in a nicer image at the cost of computional time.}
-#'  \item{"useImageSize"}{ : Boolean. Default to false. This property only applies to the image and circularImage shapes. When false, the size option is used, when true, the size of the image is used.}
-#'  \item{"useBorderWithImage"}{ : Boolean. Default to false. This property only applies to the image shape. When true, the color object is used. A rectangle with the background color is drawn behind it and it has a border. This means all border options are taken into account.}
-#'}
+#' @param shapeProperties : See \link{visDocumentation}  
 #'  
 #' @param heightConstraint : See \link{visDocumentation}  
 #' @param widthConstraint : See \link{visDocumentation}  
 #' @param margin : See \link{visDocumentation} 
 #' @param chosen : See \link{visDocumentation}  
-#'   
+#' @param imagePadding : See \link{visDocumentation}  
+#' @param ctxRenderer : See \link{visDocumentation}  
+#' 
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
 #'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
 #'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} & \link{visFocus} & \link{visFit} for animation within shiny,
@@ -157,6 +154,7 @@ visNodes <- function(graph,
                      brokenImage = NULL,
                      labelHighlightBold = NULL,
                      color = NULL,
+                     opacity = NULL,
                      fixed = NULL,
                      font = NULL,
                      icon = NULL, 
@@ -166,7 +164,9 @@ visNodes <- function(graph,
                      heightConstraint = NULL,
                      widthConstraint = NULL,
                      margin = NULL,
-                     chosen = NULL){
+                     chosen = NULL, 
+                     imagePadding = NULL, 
+                     ctxRenderer = NULL){
 
   if(!any(class(graph) %in% c("visNetwork", "visNetwork_Proxy"))){
     stop("graph must be a visNetwork or a visNetworkProxy object")
@@ -186,6 +186,7 @@ visNodes <- function(graph,
   nodes$group <- group
   nodes$hidden <- hidden
   nodes$image <- image
+  nodes$imagePadding <- imagePadding
   nodes$mass <- mass
   nodes$physics <- physics
   nodes$borderWidth <- borderWidth
@@ -193,6 +194,7 @@ visNodes <- function(graph,
   nodes$brokenImage <- brokenImage
   nodes$labelHighlightBold <- labelHighlightBold
   nodes$color <- color
+  nodes$opacity <- opacity
   nodes$fixed <- fixed
   nodes$font <- font
   nodes$icon <- icon
@@ -210,6 +212,7 @@ visNodes <- function(graph,
   }
   
   nodes$scaling <- scaling
+  nodes$ctxRenderer <- ctxRenderer
   
   if(any(class(graph) %in% "visNetwork_Proxy")){
     options <- list(nodes = nodes)
