@@ -741,14 +741,15 @@ visTreeModuleServer <- function(input, output, session, data,
       choices = 1:ncol(data())
       names(choices) = names(data())
       selected = get_tooltipColumns()
-      if(class(selected) %in% c("character", "factor")){
-        selected <- which(selected %in% names(data()))
-      }
       if(isTRUE(all.equal(selected, ""))){
         selected <- choices
+      }else if(class(selected) %in% c("character", "factor")){
+        selected <- which(selected %in% names(data()))
       }
       shiny::isolate({
-        shiny::updateSelectInput(session, inputId = "tooltipColumns", choices = choices, selected = selected)
+        shiny::updateSelectInput(session, inputId = "tooltipColumns", 
+                                 choices = choices, 
+                                 selected = selected)
       })
     } else if(!is.null(get_tooltip_data()) && "data.frame" %in% class(get_tooltip_data())){
       choices = 1:ncol(get_tooltip_data())
@@ -780,7 +781,12 @@ visTreeModuleServer <- function(input, output, session, data,
     } else {
       if(input$runTree > 0){
         shiny::isolate({
-          formule <- paste(input$y, "~", paste0(input$x, collapse = "+")) %>% as.formula()
+          if(length(input$x) > 0){
+            x_frm <- paste0("`", paste0(input$x, collapse = "` + `"), "`")
+          } else {
+            x_frm <- " . "
+          }
+          formule <- paste0("`", input$y, "` ~ ", x_frm) %>% as.formula()
           rpart::rpart(formule, data = data(), 
                        control = rpart::rpart.control(cp = input$complexity, minsplit = input$minsplit))
         })
@@ -1500,15 +1506,15 @@ visTreeModuleServer <- function(input, output, session, data,
   })
   
   # complexity update
-  cp_parameters <- shiny::reactiveValues(min = 0, max = 1,  step = 0.005)
+  cp_parameters <- shiny::reactiveValues(min = 0, max = 0.2,  step = 0.001)
   
   shiny::observeEvent(input$set_cp, {
     shiny::showModal(shiny::modalDialog(
       title = "Complexity parameters",
-      shiny::numericInput(ns("cp_min"), "Slider minimum :", shiny::isolate(cp_parameters$min)),
-      shiny::numericInput(ns("cp_max"), "Slider maximum :", shiny::isolate(cp_parameters$max)),
-      shiny::numericInput(ns("cp_step"), "Slider step :", shiny::isolate(cp_parameters$step)),
-      shiny::actionButton(ns("update_cp"), "Update complexity slider"),
+      shiny::numericInput(ns("cp_min"), "Slider minimum :", shiny::isolate(cp_parameters$min), step = 0.1),
+      shiny::numericInput(ns("cp_max"), "Slider maximum :", shiny::isolate(cp_parameters$max), step = 0.1),
+      shiny::numericInput(ns("cp_step"), "Slider step :", shiny::isolate(cp_parameters$step), step = 0.001),
+      shiny::div(shiny::actionButton(ns("update_cp"), "Update complexity slider"), align = "center"),
       easyClose = TRUE,
       footer = NULL
     ))
@@ -1519,6 +1525,7 @@ visTreeModuleServer <- function(input, output, session, data,
     cp_parameters$max <- input$cp_max
     cp_parameters$step <- input$cp_step
     shiny::updateSliderInput(session, "complexity", min = input$cp_min, max = input$cp_max, step = input$cp_step)
+    shiny::removeModal()
   })
   
   
@@ -1589,7 +1596,7 @@ visTreeModuleUI <- function(id, rpartParams = TRUE, visTreeParams = TRUE, quitBu
                                        ),
                                        shiny::column(2,
                                                      shiny::sliderInput(ns("complexity"), "Complexity (cp) :",
-                                                                        min = 0, max = 1, value = 0.005, step = 0.005)
+                                                                        min = 0, max = 0.2, value = 0.005, step = 0.001)
                                        ),
                                        shiny::column(1,
                                                      shiny::br(), shiny::br(), shiny::actionButton(ns("set_cp"), "Set cp slider")
